@@ -10,11 +10,11 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 
+#include <KMessageWidget>
 #include <QCheckBox>
 #include <QComboBox>
 #include <QDialogButtonBox>
 #include <QGroupBox>
-#include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
@@ -80,10 +80,18 @@ PushDialog::PushDialog(QWidget *parent)
     optionsGroupBox->setTitle(i18nc("@title:group", "Options"));
     QHBoxLayout *optionsHBox = new QHBoxLayout(optionsGroupBox);
     optionsGroupBox->setLayout(optionsHBox);
-    m_forceCheckBox = new QCheckBox(i18nc("@option:check", "Force"), optionsGroupBox);
-    m_forceCheckBox->setToolTip(i18nc("@info:tooltip", "Proceed even if the remote branch is not an ancestor of the local branch."));
+    m_forceCheckBox = new QCheckBox(i18nc("@option:check", "Force with lease"), optionsGroupBox);
+    m_forceCheckBox->setToolTip(
+        i18nc("@info:tooltip",
+              "Proceed even if the remote branch is not an ancestor of the local branch provided there were no changes in the remote branch since the last fetch."));
     optionsHBox->addWidget(m_forceCheckBox);
 
+    m_noRemoteMessage = new KMessageWidget(i18nc("@info no remote code repositories", "No remotes defined."), boxWidget);
+    m_noRemoteMessage->setMessageType(KMessageWidget::Warning);
+    m_noRemoteMessage->setCloseButtonVisible(false);
+    mainLayout->addWidget(m_noRemoteMessage);
+    boxLayout->addWidget(m_noRemoteMessage);
+
     mainLayout->addWidget(m_buttonBox);
 
     // populate UI
@@ -92,6 +100,7 @@ PushDialog::PushDialog(QWidget *parent)
     // get destinations
     QStringList remotes = gitWrapper->pushRemotes();
     m_remoteComboBox->addItems(remotes);
+    m_noRemoteMessage->setVisible(remotes.isEmpty());
 
     // get branch names
     int currentBranchIndex;
@@ -104,6 +113,10 @@ PushDialog::PushDialog(QWidget *parent)
             m_remoteBranches[remote] << name;
         } else {
             m_localBranchComboBox->addItem(branch);
+            const QString remote = m_remoteComboBox->currentText();
+            if (!branches.contains(QString::fromUtf8(QLatin1String("remotes/")) + remote + QLatin1String("/") + branch)) {
+                m_remoteBranches[remote] << branch;
+            }
         }
     }
     if (currentBranchIndex >= 0) {
@@ -114,6 +127,7 @@ PushDialog::PushDialog(QWidget *parent)
     // Signals
     connect(m_remoteComboBox, SIGNAL(currentTextChanged(QString)), this, SLOT(remoteSelectionChanged(QString)));
     connect(m_localBranchComboBox, SIGNAL(currentTextChanged(QString)), this, SLOT(localBranchSelectionChanged(QString)));
+    connect(m_remoteBranchComboBox, SIGNAL(currentTextChanged(QString)), this, SLOT(remoteBranchSelectionChanged(QString)));
 }
 
 QString PushDialog::destination() const
@@ -131,7 +145,7 @@ QString PushDialog::remoteBranch() const
     return m_remoteBranchComboBox->currentText();
 }
 
-bool PushDialog::force() const
+bool PushDialog::forceWithLease() const
 {
     return m_forceCheckBox->isChecked();
 }
@@ -143,15 +157,26 @@ void PushDialog::remoteSelectionChanged(const QString &newRemote)
     localBranchSelectionChanged(m_localBranchComboBox->currentText());
 }
 
+void PushDialog::remoteBranchSelectionChanged(const QString &newRemoteBranch) {
+    const bool remoteBranchExists = m_remoteBranches[destination()].contains(newRemoteBranch);
+    QPushButton *okButton = m_buttonBox->button(QDialogButtonBox::Ok);
+    if (remoteBranchExists) {
+        okButton->setText(i18nc("@action:button", "Push"));
+    } else {
+        okButton->setText(i18nc("@action:button", "Push New Branch"));
+    }
+}
+
 void PushDialog::localBranchSelectionChanged(const QString &newLocalBranch)
 {
     // select matching remote branch if possible
     const int index = m_remoteBranchComboBox->findText(newLocalBranch);
     if (index != -1) {
         m_remoteBranchComboBox->setCurrentIndex(index);
+        remoteBranchSelectionChanged(remoteBranch());
     }
     QPushButton *okButton = m_buttonBox->button(QDialogButtonBox::Ok);
-    okButton->setEnabled(m_remoteBranchComboBox->count() > 0);
+    okButton->setEnabled(m_remoteComboBox->count() > 0 && m_remoteBranchComboBox->count() > 0);
 }
 
 #include "moc_pushdialog.cpp"
