@@ -59,7 +59,6 @@ FileViewHgPlugin::FileViewHgPlugin(QObject *parent, const QList<QVariant> &args)
     , m_updateAction(nullptr)
     , m_cloneAction(nullptr)
     , m_createAction(nullptr)
-    , m_configAction(nullptr)
     , m_globalConfigAction(nullptr)
     , m_repoConfigAction(nullptr)
     , m_pushAction(nullptr)
@@ -75,7 +74,6 @@ FileViewHgPlugin::FileViewHgPlugin(QObject *parent, const QList<QVariant> &args)
     , m_diffAction(nullptr)
     , m_serveAction(nullptr)
     , m_backoutAction(nullptr)
-    , m_isCommitable(false)
     , m_hgWrapper(nullptr)
     , m_retrievalHgw(nullptr)
 {
